@@ -1,5 +1,5 @@
 from abc import ABC
-from CaptureSession import CaptureSession
+from GhostScan.CaptureSession import CaptureSession
 from GhostScan.Projections import Pattern
 
 
